MethodChannelFlutterMpPoseLandmarker class

An implementation of FlutterMpPoseLandmarkerPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkCameraPermission() Future<bool>
Checks if camera permission is granted.
override
getPlatformVersion() Future<String?>
Returns the platform version.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited